# Recipe Title

A short description of the recipe.

*tag1, tag2, tag3*

**4 servings, 1 kg**

---

- *500 g* ingredient 1
- ingredient 2 (this one has no unit, e.g for a spice that is added by taste)
- more ingredients as needed...

---

The instructions, that is how to prepare the ingredients